@@ -4,7 +4,7 @@ from pathlib import Path
 
 import httpx
 
-from .common import DEFAULT_CONFIG_FILENAME, load_yaml
+from .common import DEFAULT_CONFIG_FILENAME, load_yaml, body_to_bytes
 from .wsgi import load_app, patch_response
 
 logger = logging.getLogger(__name__)
@@ -14,6 +14,8 @@ async def call_app(app, event):
     host_url = event["headers"].get("Host", "https://raw-function.net")
     if not host_url.startswith("http"):
         host_url = f"https://{host_url}"
+    body_to_bytes(event)
+
     async with httpx.AsyncClient(app=app,
                                  base_url=host_url) as client:
         request = client.build_request(
@@ -21,7 +23,7 @@ async def call_app(app, event):
                 url=event["url"],
                 headers=event["headers"],
                 params=event["queryStringParameters"],
-                json=json.loads(event["body"]) if event["body"] else None,
+                content=event["body"],
                 )
         response = await client.send(request)
         return response
